[jboss-cvs] JBossAS SVN: r60746 - in projects/aop/trunk/aop/src: test/org/jboss/test/aop/args and 1 other directories.

jboss-cvs-commits at lists.jboss.org jboss-cvs-commits at lists.jboss.org
Tue Feb 20 18:23:21 EST 2007


Author: flavia.rainone at jboss.com
Date: 2007-02-20 18:23:21 -0500 (Tue, 20 Feb 2007)
New Revision: 60746

Removed:
   projects/aop/trunk/aop/src/main/org/jboss/aop/advice/annotation/Invocation.java
Modified:
   projects/aop/trunk/aop/src/main/org/jboss/aop/advice/annotation/JoinPoint.java
   projects/aop/trunk/aop/src/main/org/jboss/aop/advice/annotation/ParameterAnnotationRule.java
   projects/aop/trunk/aop/src/test/org/jboss/test/aop/args/ArgAspect.java
   projects/aop/trunk/aop/src/test/org/jboss/test/aop/args/InvocationAspect.java
   projects/aop/trunk/aop/src/test/org/jboss/test/aop/beforeafterArgs/ArgsAspect.java
   projects/aop/trunk/aop/src/test/org/jboss/test/aop/beforeafterArgs/InvalidAspect.java
   projects/aop/trunk/aop/src/test/org/jboss/test/aop/beforeafterArgs/OverloadedAroundAspect.java
   projects/aop/trunk/aop/src/test/org/jboss/test/aop/beforeafterArgs/ReturnAspect.java
Log:
[JBAOP-323] Changed @Invocation to @JoinPoint
(to avoid name crash with the interface org.jboss.aop.joinpoint.Invocation)

Deleted: projects/aop/trunk/aop/src/main/org/jboss/aop/advice/annotation/Invocation.java
===================================================================
--- projects/aop/trunk/aop/src/main/org/jboss/aop/advice/annotation/Invocation.java	2007-02-20 23:03:31 UTC (rev 60745)
+++ projects/aop/trunk/aop/src/main/org/jboss/aop/advice/annotation/Invocation.java	2007-02-20 23:23:21 UTC (rev 60746)
@@ -1,39 +0,0 @@
-/*
- * JBoss, Home of Professional Open Source
- * Copyright 2005, JBoss Inc., and individual contributors as indicated
- * by the @authors tag. See the copyright.txt in the distribution for a
- * full listing of individual contributors.
- *
- * This is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation; either version 2.1 of
- * the License, or (at your option) any later version.
- *
- * This software is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this software; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
- */
-package org.jboss.aop.advice.annotation;
-
-import java.lang.annotation.ElementType;
-import java.lang.annotation.Retention;
-import java.lang.annotation.RetentionPolicy;
-import java.lang.annotation.Target;
-
-/**
- * Use this annotation on the advice method parameter that receives an
- * {@link org.jboss.aop.joinpoint.Invocation} or one of its subtypes.
- * <p>
- * For optimization, always prefer to use {@link JoinPoint} instead of <code>Invocation
- * </code>.
- * 
- * @author Flavia Rainone
- */
- at Target (ElementType.PARAMETER) @Retention (RetentionPolicy.RUNTIME)
-public @interface Invocation {}
\ No newline at end of file

Modified: projects/aop/trunk/aop/src/main/org/jboss/aop/advice/annotation/JoinPoint.java
===================================================================
--- projects/aop/trunk/aop/src/main/org/jboss/aop/advice/annotation/ParameterAnnotationRule.java	2007-02-20 23:03:31 UTC (rev 60745)
+++ projects/aop/trunk/aop/src/main/org/jboss/aop/advice/annotation/ParameterAnnotationRule.java	2007-02-20 23:23:21 UTC (rev 60746)
@@ -17,8 +17,8 @@
     * Rule for parameter annotation {@link JoinPoint}.
     */
    JOIN_POINT (
-         JoinPoint.class, JoinPointInfo.class, AdviceMethodProperties.JOINPOINT_ARG, 100,
-         false, true)
+         JoinPoint.class, JoinPointInfo.class, AdviceMethodProperties.JOINPOINT_ARG,
+         100, false, true)
    {
       public Object getAssignableFrom(AdviceMethodProperties properties)
       {
@@ -30,8 +30,8 @@
     * Rule for parameter annotation {@link Invocation}.
     */
    INVOCATION (
-         org.jboss.aop.advice.annotation.Invocation.class, Invocation.class,
-         AdviceMethodProperties.INVOCATION_ARG, 100, false, true)
+         JoinPoint.class, Invocation.class, AdviceMethodProperties.INVOCATION_ARG,
+         100, false, true)
    {
       public Object getAssignableFrom(AdviceMethodProperties properties)
       {

Modified: projects/aop/trunk/aop/src/test/org/jboss/test/aop/args/ArgAspect.java
===================================================================
--- projects/aop/trunk/aop/src/test/org/jboss/test/aop/args/ArgAspect.java	2007-02-20 23:03:31 UTC (rev 60745)
+++ projects/aop/trunk/aop/src/test/org/jboss/test/aop/args/ArgAspect.java	2007-02-20 23:23:21 UTC (rev 60746)
@@ -24,7 +24,7 @@
 import junit.framework.Assert;
 
 import org.jboss.aop.advice.annotation.Arg;
-import org.jboss.aop.advice.annotation.Invocation;
+import org.jboss.aop.advice.annotation.JoinPoint;
 import org.jboss.aop.joinpoint.CurrentInvocation;
 import org.jboss.aop.joinpoint.MethodInvocation;
 
@@ -98,7 +98,7 @@
    }
 
    public int bunchArgsWithInvocation(
-         @Invocation MethodInvocation invocation,
+         @JoinPoint MethodInvocation invocation,
          @Arg int x, @Arg double y, @Arg float z, @Arg String str, @Arg int q) throws Throwable
    {
       argsWithInvocation = true;

Modified: projects/aop/trunk/aop/src/test/org/jboss/test/aop/args/InvocationAspect.java
===================================================================
--- projects/aop/trunk/aop/src/test/org/jboss/test/aop/args/InvocationAspect.java	2007-02-20 23:03:31 UTC (rev 60745)
+++ projects/aop/trunk/aop/src/test/org/jboss/test/aop/args/InvocationAspect.java	2007-02-20 23:23:21 UTC (rev 60746)
@@ -23,6 +23,7 @@
 
 import junit.framework.Assert;
 
+import org.jboss.aop.advice.annotation.JoinPoint;
 import org.jboss.aop.joinpoint.ConstructorInvocation;
 import org.jboss.aop.joinpoint.FieldInvocation;
 import org.jboss.aop.joinpoint.FieldReadInvocation;
@@ -50,31 +51,31 @@
       return "aroundMethodExecution1";
    }
    
-   public int aroundMethodExecution2(@org.jboss.aop.advice.annotation.Invocation
-         ConstructorInvocation invocation) throws Throwable
+   public int aroundMethodExecution2(@JoinPoint ConstructorInvocation invocation)
+      throws Throwable
    {
       Assert.fail("This advice should never be executed");
       return 0;
    }
    
-   public Object aroundMethodCalledByMethod(@org.jboss.aop.advice.annotation.Invocation
-         Invocation invocation) throws Throwable
+   public Object aroundMethodCalledByMethod(@JoinPoint Invocation invocation)
+      throws Throwable
    {
       advice = "aroundMethodCalledByMethod";
       invokeReturn = invocation.invokeNext();
       return 15000;
    }
    
-   public Object aroundFieldWrite(@org.jboss.aop.advice.annotation.Invocation
-         FieldInvocation invocation) throws Throwable
+   public Object aroundFieldWrite(@JoinPoint FieldInvocation invocation)
+      throws Throwable
    {
       advice = "aroundFieldWrite";
       invokeReturn = invocation.invokeNext();
       return null;
    }
    
-   public Object aroundFieldRead(@org.jboss.aop.advice.annotation.Invocation
-         FieldReadInvocation invocation) throws Throwable
+   public Object aroundFieldRead(@JoinPoint FieldReadInvocation invocation)
+      throws Throwable
    {
       advice = "aroundFieldRead";
       invokeReturn = invocation.invokeNext();

Modified: projects/aop/trunk/aop/src/test/org/jboss/test/aop/beforeafterArgs/ArgsAspect.java
===================================================================
--- projects/aop/trunk/aop/src/test/org/jboss/test/aop/beforeafterArgs/ArgsAspect.java	2007-02-20 23:03:31 UTC (rev 60745)
+++ projects/aop/trunk/aop/src/test/org/jboss/test/aop/beforeafterArgs/ArgsAspect.java	2007-02-20 23:23:21 UTC (rev 60746)
@@ -24,6 +24,7 @@
 import junit.framework.Assert;
 
 import org.jboss.aop.advice.annotation.Args;
+import org.jboss.aop.advice.annotation.JoinPoint;
 import org.jboss.aop.advice.annotation.Thrown;
 import org.jboss.aop.joinpoint.Invocation;
 import org.jboss.aop.joinpoint.MethodCalledByMethodInvocation;
@@ -223,7 +224,8 @@
       return invocation.invokeNext();
    }
    
-   public Object around3(@org.jboss.aop.advice.annotation.Invocation Invocation invocation, @Args Object[] arguments) throws Throwable
+   public Object around3(@JoinPoint Invocation invocation, @Args Object[] arguments)
+      throws Throwable
    {
       around3 = true;
       around3Args = arguments;

Modified: projects/aop/trunk/aop/src/test/org/jboss/test/aop/beforeafterArgs/InvalidAspect.java
===================================================================
--- projects/aop/trunk/aop/src/test/org/jboss/test/aop/beforeafterArgs/InvalidAspect.java	2007-02-20 23:03:31 UTC (rev 60745)
+++ projects/aop/trunk/aop/src/test/org/jboss/test/aop/beforeafterArgs/InvalidAspect.java	2007-02-20 23:23:21 UTC (rev 60746)
@@ -23,6 +23,8 @@
 
 import junit.framework.Assert;
 
+import org.jboss.aop.advice.annotation.JoinPoint;
+
 /**
  * Aspect whose advices must never be called.
  * 
@@ -33,17 +35,17 @@
  */
 public class InvalidAspect
 {
-   public void before(@org.jboss.aop.advice.annotation.Invocation Object object)
+   public void before(@JoinPoint Object object)
    {
       Assert.fail("This advice should never be executed");
    }
    
-   public void after(@org.jboss.aop.advice.annotation.Invocation Object object)
+   public void after(@JoinPoint Object object)
    {
       Assert.fail("This advice should never be executed");
    }
    
-   public void throwing(@org.jboss.aop.advice.annotation.Invocation Object object)
+   public void throwing(@JoinPoint Object object)
    {
       Assert.fail("This advice should never be executed");
    }

Modified: projects/aop/trunk/aop/src/test/org/jboss/test/aop/beforeafterArgs/OverloadedAroundAspect.java
===================================================================
--- projects/aop/trunk/aop/src/test/org/jboss/test/aop/beforeafterArgs/OverloadedAroundAspect.java	2007-02-20 23:03:31 UTC (rev 60745)
+++ projects/aop/trunk/aop/src/test/org/jboss/test/aop/beforeafterArgs/OverloadedAroundAspect.java	2007-02-20 23:23:21 UTC (rev 60746)
@@ -24,6 +24,7 @@
 import junit.framework.Assert;
 
 import org.jboss.aop.advice.annotation.Arg;
+import org.jboss.aop.advice.annotation.JoinPoint;
 import org.jboss.aop.joinpoint.ConstructorInvocation;
 import org.jboss.aop.joinpoint.CurrentInvocation;
 import org.jboss.aop.joinpoint.Invocation;
@@ -74,77 +75,77 @@
       return invocation.invokeNext();
    }
    
-   public Object around1(@org.jboss.aop.advice.annotation.Invocation
+   public Object around1(@JoinPoint
          MethodInvocation invocation, @Arg int arg1, @Arg long arg2) throws Throwable
    {
       around1 = "MethodInvocation,int,long";
       return invocation.invokeNext();
    }
    
-   public Object around1(@org.jboss.aop.advice.annotation.Invocation
+   public Object around1(@JoinPoint
          Invocation invocation, @Arg int arg1, @Arg long arg2) throws Throwable
    {
       around1 = "Invocation,int,long";
       return invocation.invokeNext();
    }
    
-   public Object around1(@org.jboss.aop.advice.annotation.Invocation
+   public Object around1(@JoinPoint
          Object invocation, @Arg int arg1, @Arg long arg2) throws Throwable
    {
       around1 = "Object,int,long";
       return ((Invocation) invocation).invokeNext();
    }
    
-   public Object around1(@org.jboss.aop.advice.annotation.Invocation
+   public Object around1(@JoinPoint
          MethodInvocation invocation, @Arg int arg1) throws Throwable
    {
       around1 = "MethodInvocation,int";
       return invocation.invokeNext();
    }
 
-   public Object around1(@org.jboss.aop.advice.annotation.Invocation
+   public Object around1(@JoinPoint
          MethodInvocation invocation, @Arg long arg2) throws Throwable
    {
       around1 = "MethodInvocation,long";
       return invocation.invokeNext();
    }
    
-   public Object around1(@org.jboss.aop.advice.annotation.Invocation
+   public Object around1(@JoinPoint
          Invocation invocation, @Arg int arg1) throws Throwable
    {
       around1 = "Invocation,int";
       return invocation.invokeNext();
    }
 
-   public Object around1(@org.jboss.aop.advice.annotation.Invocation
+   public Object around1(@JoinPoint
          Invocation invocation, @Arg long arg2) throws Throwable
    {
       around1 = "Invocation,long";
       return invocation.invokeNext();
    }
 
-   public Object around1(@org.jboss.aop.advice.annotation.Invocation
+   public Object around1(@JoinPoint
          Object invocation, @Arg int arg1) throws Throwable
    {
       around1 = "Object,int";
       return ((Invocation) invocation).invokeNext();
    }
 
-   public Object around1(@org.jboss.aop.advice.annotation.Invocation
+   public Object around1(@JoinPoint
          Object invocation, @Arg long arg2) throws Throwable
    {
       around1 = "Object,long";
       return ((Invocation) invocation).invokeNext();
    }
    
-   public Object around1(@org.jboss.aop.advice.annotation.Invocation
+   public Object around1(@JoinPoint
          MethodInvocation invocation) throws Throwable
    {
       around1 = "MethodInvocation";
       return invocation.invokeNext();
    }
    
-   public Object around1(@org.jboss.aop.advice.annotation.Invocation
+   public Object around1(@JoinPoint
          Object invocation) throws Throwable
    {
       around1 = "Object";
@@ -175,7 +176,7 @@
       return CurrentInvocation.proceed();
    }
 
-   public Object around1(@org.jboss.aop.advice.annotation.Invocation
+   public Object around1(@JoinPoint
          ConstructorInvocation invocation) throws Throwable
    {
       Assert.fail("This advice should never be executed");
@@ -184,77 +185,77 @@
    
    /* AROUND2 ADVICE */
    
-   public Object around2(@org.jboss.aop.advice.annotation.Invocation
+   public Object around2(@JoinPoint
          MethodInvocation invocation, @Arg int arg1, @Arg long arg2) throws Throwable
    {
       around2 = "MethodInvocation,int,long";
       return invocation.invokeNext();
    }
    
-   public Object around2(@org.jboss.aop.advice.annotation.Invocation
+   public Object around2(@JoinPoint
          Invocation invocation, @Arg int arg1, @Arg long arg2) throws Throwable
    {
       around2 = "Invocation,int,long";
       return invocation.invokeNext();
    }
    
-   public Object around2(@org.jboss.aop.advice.annotation.Invocation
+   public Object around2(@JoinPoint
          Object invocation, @Arg int arg1, @Arg long arg2) throws Throwable
    {
       around2 = "Object,int,long";
       return ((Invocation) invocation).invokeNext();
    }
 
-   public Object around2(@org.jboss.aop.advice.annotation.Invocation
+   public Object around2(@JoinPoint
          MethodInvocation invocation, @Arg int arg1) throws Throwable
    {
       around2 = "MethodInvocation,int";
       return invocation.invokeNext();
    }
 
-   public Object around2(@org.jboss.aop.advice.annotation.Invocation
+   public Object around2(@JoinPoint
          MethodInvocation invocation, @Arg long arg2) throws Throwable
    {
       around2 = "MethodInvocation,long";
       return invocation.invokeNext();
    }
    
-   public Object around2(@org.jboss.aop.advice.annotation.Invocation
+   public Object around2(@JoinPoint
          Invocation invocation, @Arg int arg1) throws Throwable
    {
       around2 = "Invocation,int";
       return invocation.invokeNext();
    }
 
-   public Object around2(@org.jboss.aop.advice.annotation.Invocation
+   public Object around2(@JoinPoint
          Invocation invocation, @Arg long arg2) throws Throwable
    {
       around2 = "Invocation,long";
       return invocation.invokeNext();
    }
 
-   public Object around2(@org.jboss.aop.advice.annotation.Invocation
+   public Object around2(@JoinPoint
          Object invocation, @Arg int arg1) throws Throwable
    {
       around2 = "Object,int";
       return ((Invocation) invocation).invokeNext();
    }
 
-   public Object around2(@org.jboss.aop.advice.annotation.Invocation
+   public Object around2(@JoinPoint
          Object invocation, @Arg long arg2) throws Throwable
    {
       around2 = "Object,long";
       return ((Invocation) invocation).invokeNext();
    }
 
-   public Object around2(@org.jboss.aop.advice.annotation.Invocation
+   public Object around2(@JoinPoint
          MethodInvocation invocation) throws Throwable
    {
       around2 = "MethodInvocation";
       return invocation.invokeNext();
    }
    
-   public Object around2(@org.jboss.aop.advice.annotation.Invocation
+   public Object around2(@JoinPoint
          Object invocation) throws Throwable
    {
       around2 = "Object";
@@ -285,7 +286,7 @@
       return CurrentInvocation.proceed();
    }
 
-   public Object around2(@org.jboss.aop.advice.annotation.Invocation
+   public Object around2(@JoinPoint
          ConstructorInvocation invocation) throws Throwable
    {
       Assert.fail("This advice should never be executed");
@@ -294,70 +295,70 @@
 
    /* AROUND3 ADVICE */
    
-   public Object around3(@org.jboss.aop.advice.annotation.Invocation
+   public Object around3(@JoinPoint
          Invocation invocation, @Arg int arg1, @Arg long arg2) throws Throwable
    {
       around3 = "Invocation,int,long";
       return invocation.invokeNext();
    }
 
-   public Object around3(@org.jboss.aop.advice.annotation.Invocation
+   public Object around3(@JoinPoint
          Object invocation, @Arg int arg1, @Arg long arg2) throws Throwable
    {
       around3 = "Object,int,long";
       return ((Invocation) invocation).invokeNext();
    }
 
-   public Object around3(@org.jboss.aop.advice.annotation.Invocation
+   public Object around3(@JoinPoint
          MethodInvocation invocation, @Arg int arg1) throws Throwable
    {
       around3 = "MethodInvocation,int";
       return invocation.invokeNext();
    }
 
-   public Object around3(@org.jboss.aop.advice.annotation.Invocation
+   public Object around3(@JoinPoint
          MethodInvocation invocation, @Arg long arg2) throws Throwable
    {
       around3 = "MethodInvocation,long";
       return invocation.invokeNext();
    }
    
-   public Object around3(@org.jboss.aop.advice.annotation.Invocation
+   public Object around3(@JoinPoint
          Invocation invocation, @Arg int arg1) throws Throwable
    {
       around3 = "Invocation,int";
       return invocation.invokeNext();
    }
 
-   public Object around3(@org.jboss.aop.advice.annotation.Invocation
+   public Object around3(@JoinPoint
          Invocation invocation, @Arg long arg2) throws Throwable
    {
       around3 = "Invocation,long";
       return invocation.invokeNext();
    }
 
-   public Object around3(@org.jboss.aop.advice.annotation.Invocation
+   public Object around3(@JoinPoint
          Object invocation, @Arg int arg1) throws Throwable
    {
       around3 = "Object,int";
       return ((Invocation) invocation).invokeNext();
    }
 
-   public Object around3(@org.jboss.aop.advice.annotation.Invocation
+   public Object around3(@JoinPoint
          Object invocation, @Arg long arg2) throws Throwable
    {
       around3 = "Object,long";
       return ((Invocation) invocation).invokeNext();
    }
 
-   public Object around3(@org.jboss.aop.advice.annotation.Invocation
+   public Object around3(@JoinPoint
          MethodInvocation invocation) throws Throwable
    {
       around3 = "MethodInvocation";
       return invocation.invokeNext();
    }
 
-   public Object around3(@org.jboss.aop.advice.annotation.Invocation
+   public Object around3(@JoinPoint
          Object invocation) throws Throwable
    {
       around3 = "Object";
@@ -388,7 +389,7 @@
       return CurrentInvocation.proceed();
    }
 
-   public Object around3(@org.jboss.aop.advice.annotation.Invocation
+   public Object around3(@JoinPoint
          ConstructorInvocation invocation) throws Throwable
    {
       Assert.fail("This advice should never be executed");
@@ -397,63 +398,63 @@
 
    /* AROUND4 ADVICE */
    
-   public Object around4(@org.jboss.aop.advice.annotation.Invocation
+   public Object around4(@JoinPoint
          Object invocation, @Arg int arg1, @Arg long arg2) throws Throwable
    {
       around4 = "Object,int,long";
       return ((Invocation) invocation).invokeNext();
    }
 
-   public Object around4(@org.jboss.aop.advice.annotation.Invocation
+   public Object around4(@JoinPoint
          MethodInvocation invocation, @Arg int arg1) throws Throwable
    {
       around4 = "MethodInvocation,int";
       return invocation.invokeNext();
    }
 
-   public Object around4(@org.jboss.aop.advice.annotation.Invocation
+   public Object around4(@JoinPoint
          MethodInvocation invocation, @Arg long arg2) throws Throwable
    {
       around4 = "MethodInvocation,long";
       return invocation.invokeNext();
    }
    
-   public Object around4(@org.jboss.aop.advice.annotation.Invocation
+   public Object around4(@JoinPoint
          Invocation invocation, @Arg int arg1) throws Throwable
    {
       around4 = "Invocation,int";
       return invocation.invokeNext();
    }
 
-   public Object around4(@org.jboss.aop.advice.annotation.Invocation
+   public Object around4(@JoinPoint
          Invocation invocation, @Arg long arg2) throws Throwable
    {
       around4 = "Invocation,long";
       return invocation.invokeNext();
    }
 
-   public Object around4(@org.jboss.aop.advice.annotation.Invocation
+   public Object around4(@JoinPoint
          Object invocation, @Arg int arg1) throws Throwable
    {
       around4 = "Object,int";
       return ((Invocation) invocation).invokeNext();
    }
 
-   public Object around4(@org.jboss.aop.advice.annotation.Invocation
+   public Object around4(@JoinPoint
          Object invocation, @Arg long arg2) throws Throwable
    {
       around4 = "Object,long";
       return ((Invocation) invocation).invokeNext();
    }
 
-   public Object around4(@org.jboss.aop.advice.annotation.Invocation
+   public Object around4(@JoinPoint
          MethodInvocation invocation) throws Throwable
    {
       around4 = "MethodInvocation";
       return invocation.invokeNext();
    }
 
-   public Object around4(@org.jboss.aop.advice.annotation.Invocation
+   public Object around4(@JoinPoint
          Object invocation) throws Throwable
    {
       around4 = "Object";
@@ -484,7 +485,7 @@
       return CurrentInvocation.proceed();
    }
 
-   public Object around4(@org.jboss.aop.advice.annotation.Invocation
+   public Object around4(@JoinPoint
          ConstructorInvocation invocation) throws Throwable
    {
       Assert.fail("This advice should never be executed");
@@ -493,56 +494,56 @@
 
    /* AROUND5 ADVICE */
    
-   public Object around5(@org.jboss.aop.advice.annotation.Invocation
+   public Object around5(@JoinPoint
          MethodInvocation invocation, @Arg int arg1) throws Throwable
    {
       around5 = "MethodInvocation,int";
       return invocation.invokeNext();
    }
 
-   public Object around5(@org.jboss.aop.advice.annotation.Invocation
+   public Object around5(@JoinPoint
          MethodInvocation invocation, @Arg long arg2) throws Throwable
    {
       around5 = "MethodInvocation,long";
       return invocation.invokeNext();
    }
 
-   public Object around5(@org.jboss.aop.advice.annotation.Invocation
+   public Object around5(@JoinPoint
          Invocation invocation, @Arg int arg1) throws Throwable
    {
       around5 = "Invocation,int";
       return invocation.invokeNext();
    }
 
-   public Object around5(@org.jboss.aop.advice.annotation.Invocation
+   public Object around5(@JoinPoint
          Invocation invocation, @Arg long arg2) throws Throwable
    {
       around5 = "Invocation,long";
       return invocation.invokeNext();
    }
 
-   public Object around5(@org.jboss.aop.advice.annotation.Invocation
+   public Object around5(@JoinPoint
          Object invocation, @Arg int arg1) throws Throwable
    {
       around5 = "Object,int";
       return ((Invocation) invocation).invokeNext();
    }
 
-   public Object around5(@org.jboss.aop.advice.annotation.Invocation
+   public Object around5(@JoinPoint
          Object invocation, @Arg long arg2) throws Throwable
    {
       around5 = "Object,long";
       return ((Invocation) invocation).invokeNext();
    }
 
-   public Object around5(@org.jboss.aop.advice.annotation.Invocation
+   public Object around5(@JoinPoint
          MethodInvocation invocation) throws Throwable
    {
       around5 = "MethodInvocation";
       return invocation.invokeNext();
    }
 
-   public Object around5(@org.jboss.aop.advice.annotation.Invocation
+   public Object around5(@JoinPoint
          Object invocation) throws Throwable
    {
       around5 = "Object";
@@ -573,7 +574,7 @@
       return CurrentInvocation.proceed();
    }
    
-   public Object around5(@org.jboss.aop.advice.annotation.Invocation
+   public Object around5(@JoinPoint
          ConstructorInvocation invocation) throws Throwable
    {
       Assert.fail("This advice should never be executed");
@@ -582,42 +583,42 @@
 
    /* AROUND6 ADVICE */
    
-   public Object around6(@org.jboss.aop.advice.annotation.Invocation
+   public Object around6(@JoinPoint
          Invocation invocation, @Arg int arg1) throws Throwable
    {
       around6 = "Invocation,int";
       return invocation.invokeNext();
    }
 
-   public Object aroun6(@org.jboss.aop.advice.annotation.Invocation
+   public Object aroun6(@JoinPoint
          Invocation invocation, @Arg long arg2) throws Throwable
    {
       around6 = "Invocation,long";
       return invocation.invokeNext();
    }
 
-   public Object around6(@org.jboss.aop.advice.annotation.Invocation
+   public Object around6(@JoinPoint
          Object invocation, @Arg int arg1) throws Throwable
    {
       around6 = "Object,int";
       return ((Invocation) invocation).invokeNext();
    }
 
-   public Object around6(@org.jboss.aop.advice.annotation.Invocation
+   public Object around6(@JoinPoint
          Object invocation, @Arg long arg2) throws Throwable
    {
       around6 = "Object,long";
       return ((Invocation) invocation).invokeNext();
    }
 
-   public Object around6(@org.jboss.aop.advice.annotation.Invocation
+   public Object around6(@JoinPoint
          MethodInvocation invocation) throws Throwable
    {
       around6 = "MethodInvocation";
       return invocation.invokeNext();
    }
    
-   public Object around6(@org.jboss.aop.advice.annotation.Invocation
+   public Object around6(@JoinPoint
          Object invocation) throws Throwable
    {
       around6 = "Object";
@@ -648,7 +649,7 @@
       return CurrentInvocation.proceed();
    }
 
-   public Object around6(@org.jboss.aop.advice.annotation.Invocation
+   public Object around6(@JoinPoint
          ConstructorInvocation invocation) throws Throwable
    {
       Assert.fail("This advice should never be executed");
@@ -657,28 +658,28 @@
 
    /* AROUND7 ADVICE */
    
-   public Object around7(@org.jboss.aop.advice.annotation.Invocation
+   public Object around7(@JoinPoint
          Object invocation, @Arg int arg1) throws Throwable
    {
       around7 = "Object,int";
       return ((Invocation) invocation).invokeNext();
    }
 
-   public Object around7(@org.jboss.aop.advice.annotation.Invocation
+   public Object around7(@JoinPoint
          Object invocation, @Arg long arg2) throws Throwable
    {
       around7 = "Object,long";
       return ((Invocation) invocation).invokeNext();
    }
 
-   public Object around7(@org.jboss.aop.advice.annotation.Invocation
+   public Object around7(@JoinPoint
          MethodInvocation invocation) throws Throwable
    {
       around7 = "MethodInvocation";
       return invocation.invokeNext();
    }
    
-   public Object around7(@org.jboss.aop.advice.annotation.Invocation
+   public Object around7(@JoinPoint
          Object invocation) throws Throwable
    {
       around7 = "Object";
@@ -709,7 +710,7 @@
       return CurrentInvocation.proceed();
    }
 
-   public Object around7(@org.jboss.aop.advice.annotation.Invocation
+   public Object around7(@JoinPoint
          ConstructorInvocation invocation) throws Throwable
    {
       Assert.fail("This advice should never be executed");
@@ -718,14 +719,14 @@
 
    /* AROUND8 ADVICE */
    
-   public Object around8(@org.jboss.aop.advice.annotation.Invocation
+   public Object around8(@JoinPoint
          MethodInvocation invocation) throws Throwable
    {
       around8 = "MethodInvocation";
       return invocation.invokeNext();
    }
 
-   public Object around8(@org.jboss.aop.advice.annotation.Invocation
+   public Object around8(@JoinPoint
          Object invocation) throws Throwable
    {
       around8 = "Object";
@@ -756,7 +757,7 @@
       return CurrentInvocation.proceed();
    }
 
-   public Object around8(@org.jboss.aop.advice.annotation.Invocation
+   public Object around8(@JoinPoint
          ConstructorInvocation invocation) throws Throwable
    {
       Assert.fail("This advice should never be executed");
@@ -765,7 +766,7 @@
 
    /* AROUND9 ADVICE */
    
-   public Object around9(@org.jboss.aop.advice.annotation.Invocation
+   public Object around9(@JoinPoint
          Object invocation) throws Throwable
    {
       around9 = "Object";
@@ -796,7 +797,7 @@
       return CurrentInvocation.proceed();
    }
 
-   public Object around9(@org.jboss.aop.advice.annotation.Invocation
+   public Object around9(@JoinPoint
          ConstructorInvocation invocation) throws Throwable
    {
       Assert.fail("This advice should never be executed");
@@ -829,7 +830,7 @@
       return CurrentInvocation.proceed();
    }
    
-   public Object around10(@org.jboss.aop.advice.annotation.Invocation
+   public Object around10(@JoinPoint
          ConstructorInvocation invocation) throws Throwable
    {
       Assert.fail("This advice should never be executed");
@@ -856,7 +857,7 @@
       return CurrentInvocation.proceed();
    }
    
-   public Object around11(@org.jboss.aop.advice.annotation.Invocation
+   public Object around11(@JoinPoint
          ConstructorInvocation invocation) throws Throwable
    {
       Assert.fail("This advice should never be executed");
@@ -871,7 +872,7 @@
       return CurrentInvocation.proceed();
    }
    
-   public Object around12(@org.jboss.aop.advice.annotation.Invocation
+   public Object around12(@JoinPoint
          ConstructorInvocation invocation) throws Throwable
    {
       Assert.fail("This advice should never be executed");

Modified: projects/aop/trunk/aop/src/test/org/jboss/test/aop/beforeafterArgs/ReturnAspect.java
===================================================================
--- projects/aop/trunk/aop/src/test/org/jboss/test/aop/beforeafterArgs/ReturnAspect.java	2007-02-20 23:03:31 UTC (rev 60745)
+++ projects/aop/trunk/aop/src/test/org/jboss/test/aop/beforeafterArgs/ReturnAspect.java	2007-02-20 23:23:21 UTC (rev 60746)
@@ -63,7 +63,7 @@
       Assert.fail("This advice should never be executed");
    }
    
-   public void around2(@org.jboss.aop.advice.annotation.Invocation
+   public void around2(@JoinPoint
          Invocation invocation) throws Exception
    {
       Assert.fail("This advice should never be executed");
@@ -76,7 +76,7 @@
       return aroundAdvice;
    }
    
-   public Object around4(@org.jboss.aop.advice.annotation.Invocation
+   public Object around4(@JoinPoint
          Invocation invocation) throws Throwable
    {
       aroundAdvice = "around4";
@@ -95,7 +95,7 @@
       Assert.fail("This advice should never be executed");
    }
    
-   public String around7(@org.jboss.aop.advice.annotation.Invocation Invocation
+   public String around7(@JoinPoint Invocation
          invocation) throws Throwable
    {
       aroundAdvice = "around7";
@@ -109,14 +109,14 @@
       return new SubValue(80);
    }
    
-   public SuperValue around9(@org.jboss.aop.advice.annotation.Invocation Invocation
+   public SuperValue around9(@JoinPoint Invocation
          invocation) throws Throwable
    {
       Assert.fail("This advice should never be executed");
       return null;
    }
    
-   public SubValue around10(@org.jboss.aop.advice.annotation.Invocation Invocation
+   public SubValue around10(@JoinPoint Invocation
          invocation) throws Throwable
    {
       aroundAdvice = "around10";
@@ -124,7 +124,7 @@
       return new SubValue(100);
    }
    
-   public SuperValue around11(@org.jboss.aop.advice.annotation.Invocation Invocation
+   public SuperValue around11(@JoinPoint Invocation
          invocation) throws Throwable
    {
       aroundAdvice = "around11";




More information about the jboss-cvs-commits mailing list
--- projects/aop/trunk/aop/src/main/org/jboss/aop/advice/annotation/JoinPoint.java	2007-02-20 23:03:31 UTC (rev 60745)
+++ projects/aop/trunk/aop/src/main/org/jboss/aop/advice/annotation/JoinPoint.java	2007-02-20 23:23:21 UTC (rev 60746)
@@ -27,10 +27,16 @@
 import java.lang.annotation.Target;
 
 import org.jboss.aop.JoinPointInfo;
+import org.jboss.aop.joinpoint.Invocation;
 
 /**
  * Use this annotation on the advice parameter that receives {@link JoinPointInfo} or
  * one of its subtypes.
  * 
  * @author Flavia Rainone
  */
@@ -27,10 +27,16 @@
 
 /**
- * Use this annotation on the advice parameter that receives {@link JoinPointInfo} or
- * one of its subtypes.
+ * Use this annotation on the advice parameter that receives:
+ * <ul>
+ * <li>{@link JoinPointInfo} or one of its subtypes (for before, after and throwing
+ * advices);</li>
+ * <li>{@link Invocation} or one of its subtypes (for around
+ * advices).</li>
+ * </ul>
  * 
  * @author Flavia Rainone

Modified: projects/aop/trunk/aop/src/main/org/jboss/aop/advice/annotation/ParameterAnnotationRule.java
===================================================================